@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,7 +22,6 @@
 #include "DigiDoc.h"
 
 #include "common/SslCertificate.h"
-#include "common/sslConnect.h"
 
 #include "QMobileSigner.h"
 #include "QSigner.h"
@@ -43,9 +41,6 @@
 
 #include <stdexcept>
 
-#ifndef BDOCLIB_CONF_PATH
-#define BDOCLIB_CONF_PATH "digidocpp.conf"
-#endif
 
 using namespace digidoc;
 
@@ -60,7 +55,7 @@ QSslCertificate DigiDocSignature::cert() const
 	try
 	{
 		X509 *x509 = s->getSigningCertificate().getX509();
-		c = SslCertificate::fromX509( (Qt::HANDLE)x509 );
+		c = SslCertificate::fromX509( Qt::HANDLE(x509) );
 		X509_free( x509 );
 	}
 	catch( const Exception & ) {}
@@ -70,23 +65,28 @@ QSslCertificate DigiDocSignature::cert() const
 QDateTime DigiDocSignature::dateTime() const
 {
 	QString dateTime;
-	Signature *sc = const_cast<Signature*>(s);
-	if( s->getMediaType().compare( "signature/bdoc-1.0/TM" ) == 0 )
+	switch( type() )
 	{
-		SignatureTM *tm = static_cast<SignatureTM*>(sc);
-		dateTime = QString::fromStdString( tm->getProducedAt() );
+	case TMType:
+		dateTime = QString::fromUtf8(
+			static_cast<const SignatureTM*>(s)->getProducedAt().c_str() );
+		break;
+	case DDocType:
+		dateTime = QString::fromUtf8(
+			static_cast<const SignatureDDOC*>(s)->getProducedAt().c_str() );
+		break;
+	default: break;
 	}
-	else if( s->getMediaType().compare( 0, 11, "DIGIDOC-XML" ) == 0 ||
-		s->getMediaType().compare( 0, 6, "SK-XML" ) == 0 )
-	{
-		SignatureDDOC *ddoc = static_cast<SignatureDDOC*>(sc);
-		dateTime = QString::fromStdString( ddoc->getProducedAt() );
-	}
-	else
-		dateTime = QString::fromStdString( s->getSigningTime() );
 
-	return SslCertificate::toLocalTime( QDateTime::fromString(
-		dateTime, "yyyy-MM-dd'T'hh:mm:ss'Z'" ) );
+	if( dateTime.isEmpty() )
+		dateTime = QString::fromUtf8( s->getSigningTime().c_str() );
+
+	if( dateTime.isEmpty() )
+		return QDateTime();
+
+	QDateTime date = QDateTime::fromString( dateTime, "yyyy-MM-dd'T'hh:mm:ss'Z'" );
+	date.setTimeSpec( Qt::UTC );
+	return date.toLocalTime();
 }
 
 QString DigiDocSignature::digestMethod() const
@@ -95,18 +95,17 @@ QString DigiDocSignature::digestMethod() const
 	{
 		std::vector<unsigned char> data;
 		std::string method;
-		Signature *sc = const_cast<Signature*>(s);
 		switch( type() )
 		{
 		case TMType:
-			static_cast<SignatureTM*>(sc)->getRevocationOCSPRef( data, method );
+			static_cast<const SignatureTM*>(s)->getRevocationOCSPRef( data, method );
 			break;
 		case DDocType:
-			static_cast<SignatureDDOC*>(sc)->getRevocationOCSPRef( data, method );
+			static_cast<const SignatureDDOC*>(s)->getRevocationOCSPRef( data, method );
 			break;
 		default: return QString();
 		}
-		return QString::fromStdString( method );
+		return QString::fromUtf8( method.c_str() );
 	}
 	catch( const Exception & ) {}
 	return QString();
@@ -118,14 +117,13 @@ QByteArray DigiDocSignature::digestValue() const
 	{
 		std::vector<unsigned char> data;
 		std::string method;
-		Signature *sc = const_cast<Signature*>(s);
 		switch( type() )
 		{
 		case TMType:
-			static_cast<SignatureTM*>(sc)->getRevocationOCSPRef( data, method );
+			static_cast<const SignatureTM*>(s)->getRevocationOCSPRef( data, method );
 			break;
 		case DDocType:
-			static_cast<SignatureDDOC*>(sc)->getRevocationOCSPRef( data, method );
+			static_cast<const SignatureDDOC*>(s)->getRevocationOCSPRef( data, method );
 			break;
 		default: return QByteArray();
 		}
@@ -136,6 +134,106 @@ QByteArray DigiDocSignature::digestValue() const
 	return QByteArray();
 }
 
+QString DigiDocSignature::lastError() const { return m_lastError; }
+
+QString DigiDocSignature::location() const
+{
+	QStringList l = locations();
+	l.removeAll( "" );
+	return l.join( ", " );
+}
+
+QStringList DigiDocSignature::locations() const
+{
+	QStringList l;
+	const SignatureProductionPlace p = s->getProductionPlace();
+	l << QString::fromUtf8( p.city.c_str() ).trimmed();
+	l << QString::fromUtf8( p.stateOrProvince.c_str() ).trimmed();
+	l << QString::fromUtf8( p.postalCode.c_str() ).trimmed();
+	l << QString::fromUtf8( p.countryName.c_str() ).trimmed();
+	return l;
+}
+
+QString DigiDocSignature::mediaType() const
+{ return QString::fromUtf8( s->getMediaType().c_str() ); }
+
+QSslCertificate DigiDocSignature::ocspCert() const
+{
+	try
+	{
+		switch( type() )
+		{
+		case TMType:
+			return SslCertificate::fromX509( Qt::HANDLE(
+				static_cast<const SignatureTM*>(s)->getOCSPCertificate().getX509()) );
+		case DDocType:
+			return SslCertificate::fromX509( Qt::HANDLE(
+				static_cast<const SignatureDDOC*>(s)->getOCSPCertificate().getX509()) );
+		default: return QSslCertificate();
+		}
+	}
+	catch( const Exception & ) {}
+		return QSslCertificate();
+}
+
+DigiDoc* DigiDocSignature::parent() const { return m_parent; }
+
+int DigiDocSignature::parseException( const digidoc::Exception &e )
+{
+	Q_FOREACH( const Exception &c, e.getCauses() )
+	{
+		int code = parseException( c );
+		if( code != Exception::NoException )
+			return code;
+	}
+	return e.code();
+}
+
+void DigiDocSignature::parseExceptionStrings( const digidoc::Exception &e, QStringList &causes )
+{
+	causes << QString::fromUtf8( e.getMsg().c_str() );
+	Q_FOREACH( const Exception &c, e.getCauses() )
+		parseExceptionStrings( c, causes );
+}
+
+QString DigiDocSignature::role() const
+{
+	QStringList r = roles();
+	r.removeAll( "" );
+	return r.join( ", " );
+}
+
+QStringList DigiDocSignature::roles() const
+{
+	QStringList list;
+	const SignerRole::TRoles roles = s->getSignerRole().claimedRoles;
+	SignerRole::TRoles::const_iterator i = roles.begin();
+	for( ; i != roles.end(); ++i )
+		list << QString::fromUtf8( i->data() ).trimmed();
+	return list;
+}
+
+void DigiDocSignature::setLastError( const Exception &e )
+{
+	QStringList causes;
+	parseExceptionStrings( e, causes );
+	m_lastError = causes.join( "<br />" );
+}
+
+DigiDocSignature::SignatureType DigiDocSignature::type() const
+{
+	if( s->getMediaType().compare( "signature/bdoc-1.0/TM" ) == 0 )
+		return TMType;
+	if( s->getMediaType().compare( "signature/bdoc-1.0/TS" ) == 0 )
+		return TSType;
+	if( s->getMediaType().compare( "signature/bdoc-1.0/BES" ) == 0 )
+		return BESType;
+	if( s->getMediaType().compare( 0, 11, "DIGIDOC-XML" ) == 0 ||
+		s->getMediaType().compare( 0, 6, "SK-XML" ) == 0 )
+		return DDocType;
+	return UnknownType;
+}
+
 DigiDocSignature::SignatureStatus DigiDocSignature::validate()
 {
 	try
@@ -156,112 +254,29 @@ DigiDocSignature::SignatureStatus DigiDocSignature::validate()
 	catch( const Exception &e )
 	{
 		setLastError( e );
-		if( e.code() == Exception::OCSPResponderMissing )
-			return Unknown;
+		switch( parseException( e ) )
+		{
+		case Exception::CertificateIssuerMissing:
+		case Exception::CertificateUnknown:
+		case Exception::OCSPResponderMissing:
+		case Exception::OCSPCertMissing: return Unknown;
+		default: break;
+		}
 	}
 	return Invalid;
 }
 
-QString DigiDocSignature::lastError() const { return m_lastError; }
-
-QString DigiDocSignature::location() const
-{
-	QStringList l = locations();
-	l.removeAll( "" );
-	return l.join( ", " );
-}
-
-QStringList DigiDocSignature::locations() const
-{
-	QStringList l;
-	const Signer::SignatureProductionPlace p = s->getProductionPlace();
-	l << QString::fromUtf8( p.city.data() ).trimmed();
-	l << QString::fromUtf8( p.stateOrProvince.data() ).trimmed();
-	l << QString::fromUtf8( p.postalCode.data() ).trimmed();
-	l << QString::fromUtf8( p.countryName.data() ).trimmed();
-	return l;
-}
-
-QString DigiDocSignature::mediaType() const
-{ return QString::fromUtf8( s->getMediaType().data() ); }
-
-QSslCertificate DigiDocSignature::ocspCert() const
-{
-	Signature *sc = const_cast<Signature*>(s);
-	try
-	{
-		switch( type() )
-		{
-		case TMType:
-		{
-			X509Cert cert = static_cast<SignatureTM*>(sc)->getOCSPCertificate();
-			return SslCertificate::fromX509( Qt::HANDLE(cert.getX509()) );
-		}
-		case DDocType:
-		{
-			X509Cert cert = static_cast<SignatureDDOC*>(sc)->getOCSPCertificate();
-			return SslCertificate::fromX509( Qt::HANDLE(cert.getX509()) );
-		}
-		default: return QSslCertificate();
-		}
-	}
-	catch( const Exception & ) {}
-		return QSslCertificate();
-}
-
-DigiDoc* DigiDocSignature::parent() const { return m_parent; }
-
-QString DigiDocSignature::role() const
-{
-	QStringList r = roles();
-	r.removeAll( "" );
-	return r.join( ", " );
-}
-
-QStringList DigiDocSignature::roles() const
-{
-	QStringList list;
-	const Signer::SignerRole::TRoles roles = s->getSignerRole().claimedRoles;
-	Signer::SignerRole::TRoles::const_iterator i = roles.begin();
-	for( ; i != roles.end(); ++i )
-		list << QString::fromUtf8( i->data() ).trimmed();
-	return list;
-}
-
-void DigiDocSignature::setLastError( const Exception &e )
-{
-	QStringList causes;
-	causes << QString::fromUtf8( e.getMsg().data() );
-	Q_FOREACH( const Exception &c, e.getCauses() )
-		causes << QString::fromUtf8( c.getMsg().data() );
-	m_lastError = causes.join( "\n" );
-}
-
-DigiDocSignature::SignatureType DigiDocSignature::type() const
-{
-	if( s->getMediaType().compare( "signature/bdoc-1.0/TM" ) == 0 )
-		return TMType;
-	if( s->getMediaType().compare( "signature/bdoc-1.0/TS" ) == 0 )
-		return TSType;
-	if( s->getMediaType().compare( "signature/bdoc-1.0/BES" ) == 0 )
-		return BESType;
-	if( s->getMediaType().compare( 0, 11, "DIGIDOC-XML" ) == 0 ||
-		s->getMediaType().compare( 0, 6, "SK-XML" ) == 0 )
-		return DDocType;
-	return UnknownType;
-}
-
 
 
 DigiDoc::DigiDoc( QObject *parent )
 :	QObject( parent )
 ,	b(0)
-,	signer(0)
+,	m_signer(0)
 {}
 
 DigiDoc::~DigiDoc()
 {
-	delete signer;
+	delete m_signer;
 	clear();
 	X509CertStore::destroy();
 	digidoc::terminate();
@@ -349,40 +364,10 @@ QList<Document> DigiDoc::documents()
 	return list;
 }
 
-QString DigiDoc::getAccessCert()
-{
-	QString buffer;
-
-	signer->unloadDriver();
-	try {
-		SSLConnect sslConnect;
-		sslConnect.setPKCS11( getConfValue( PKCS11Module ) );
-		sslConnect.setCard( m_card );
-		buffer = QString::fromUtf8( sslConnect.getUrl( SSLConnect::AccessCert, "" ) );
-	} catch( const std::runtime_error &e ) {
-		if( !QByteArray( e.what() ).isEmpty() )
-			setLastError( e.what() );
-	}
-
-	signer->start();
-
-	return buffer;
-}
-
 QString DigiDoc::fileName() const { return m_fileName; }
 
 bool DigiDoc::init()
 {
-	if( qgetenv( "BDOCLIB_CONF_XML" ).isEmpty() )
-	{
-		QByteArray path = QSettings( QSettings::NativeFormat, QSettings::SystemScope,
-			"Estonian ID Card", "digidocpp" ).value( "ConfigFile" ).toByteArray();
-		if( !path.isEmpty() )
-			qputenv( "BDOCLIB_CONF_XML", path );
-		else
-			qputenv( "BDOCLIB_CONF_XML", BDOCLIB_CONF_PATH );
-	}
-
 	try
 	{
 		digidoc::initialize();
@@ -390,11 +375,11 @@ bool DigiDoc::init()
 	}
 	catch( const Exception &e ) { setLastError( e ); return false; }
 
-	signer = new QSigner();
-	connect( signer, SIGNAL(dataChanged(QStringList,QString,QSslCertificate)),
+	m_signer = new QSigner();
+	connect( m_signer, SIGNAL(dataChanged(QStringList,QString,QSslCertificate)),
 		SLOT(dataChanged(QStringList,QString,QSslCertificate)) );
-	connect( signer, SIGNAL(error(QString)), SLOT(setLastError(QString)) );
-	signer->start();
+	connect( m_signer, SIGNAL(error(QString)), SLOT(setLastError(QString)) );
+	m_signer->start();
 	return true;
 }
 
@@ -407,43 +392,38 @@ bool DigiDoc::open( const QString &file )
 	m_fileName = file;
 	try
 	{
-		std::auto_ptr<ISerialize> s(new ZipSerialize(file.toUtf8().constData()));
-		b = new WDoc( s );
+		b = new WDoc( file.toUtf8().constData() );
 		return true;
 	}
 	catch( const Exception &e )
 	{
 		QStringList causes;
-		parseException( e, causes );
+		Exception::ExceptionCode code;
+		parseException( e, causes, code );
 		setLastError( tr("An error occurred while opening the document.<br />%1").arg( causes.join("\n") ) );
 	}
 	return false;
 }
 
-bool DigiDoc::parseException( const Exception &e, QStringList &causes )
+bool DigiDoc::parseException( const Exception &e, QStringList &causes, Exception::ExceptionCode &code )
 {
 	switch( e.code() )
 	{
 	case Exception::CertificateRevoked:
-		setLastError( tr("Certificate status revoked") ); return false;
 	case Exception::CertificateUnknown:
-		setLastError( tr("Certificate status unknown") ); return false;
 	case Exception::OCSPTimeSlot:
-		setLastError( tr("Check your computer time") ); return false;
+	case Exception::OCSPRequestUnauthorized:
 	case Exception::PINCanceled:
-		return false;
 	case Exception::PINFailed:
-		setLastError( tr("PIN Login failed") ); return false;
 	case Exception::PINIncorrect:
-		setLastError( tr("PIN Incorrect") ); return false;
 	case Exception::PINLocked:
-		setLastError( tr("PIN Locked") ); return false;
+		code = e.code(); return false;
 	default:
-		causes << QString::fromUtf8( e.getMsg().data() );
+		causes << QString::fromUtf8( e.getMsg().c_str() );
 		break;
 	}
 	Q_FOREACH( const Exception &c, e.getCauses() )
-		if( !parseException( c, causes ) )
+		if( !parseException( c, causes, code ) )
 			return false;
 	return true;
 }
@@ -478,25 +458,10 @@ void DigiDoc::save()
 	catch( const Exception &e ) { setLastError( e ); }
 }
 
-void DigiDoc::saveDocument( unsigned int num, const QString &filepath )
-{
-	if( !checkDoc( num >= b->documentCount(), tr("Missing document") ) )
-		return;
-	try
-	{
-		digidoc::Document doc = b->getDocument( num );
-		if( doc.getPath().data() == filepath.toUtf8() )
-			return;
-		QFile::remove( filepath );
-		doc.saveAs( filepath.toUtf8().constData() );
-	}
-	catch( const Exception &e ) { setLastError( e ); }
-}
-
 void DigiDoc::selectCard( const QString &card )
-{ QMetaObject::invokeMethod( signer, "selectCard", Qt::QueuedConnection, Q_ARG(QString,card) ); }
+{ QMetaObject::invokeMethod( m_signer, "selectCard", Qt::QueuedConnection, Q_ARG(QString,card) ); }
 
-QString DigiDoc::getConfValue( ConfParameter parameter, const QVariant &value ) const
+QString DigiDoc::getConfValue( ConfParameter parameter, const QVariant &value )
 {
 	digidoc::Conf *i = NULL;
 	try { i = digidoc::Conf::getInstance(); }
@@ -539,8 +504,29 @@ void DigiDoc::setConfValue( ConfParameter parameter, const QVariant &value )
 void DigiDoc::setLastError( const Exception &e )
 {
 	QStringList causes;
-	if( parseException( e, causes ) )
-		setLastError( causes.join( "\n" ) );
+	Exception::ExceptionCode code;
+	parseException( e, causes, code );
+	switch( code )
+	{
+	case Exception::CertificateRevoked:
+		setLastError( tr("Certificate status revoked") ); break;
+	case Exception::CertificateUnknown:
+		setLastError( tr("Certificate status unknown") ); break;
+	case Exception::OCSPTimeSlot:
+		setLastError( tr("Check your computer time") ); break;
+	case Exception::OCSPRequestUnauthorized:
+		setLastError( tr("Server access certificate is required")); break;
+	case Exception::PINCanceled:
+		break;
+	case Exception::PINFailed:
+		setLastError( tr("PIN Login failed") ); break;
+	case Exception::PINIncorrect:
+		setLastError( tr("PIN Incorrect") ); break;
+	case Exception::PINLocked:
+		setLastError( tr("PIN Locked") ); break;
+	default:
+		setLastError( causes.join( "\n" ) ); break;
+	}
 }
 
 void DigiDoc::setLastError( const QString &err ) { Q_EMIT error( m_lastError = err ); }
@@ -554,23 +540,36 @@ bool DigiDoc::sign( const QString &city, const QString &state, const QString &zi
 	bool result = false;
 	try
 	{
-		signer->setSignatureProductionPlace( Signer::SignatureProductionPlace(
+		m_signer->setSignatureProductionPlace( SignatureProductionPlace(
 			city.toUtf8().constData(),
 			state.toUtf8().constData(),
 			zip.toUtf8().constData(),
 			country.toUtf8().constData() ) );
-		Signer::SignerRole sRole( role.toUtf8().constData() );
+		SignerRole sRole( role.toUtf8().constData() );
 		if ( !role2.isEmpty() )
 			sRole.claimedRoles.push_back( role2.toUtf8().constData() );
-		signer->setSignerRole( sRole );
-		b->sign( signer, Signature::TM );
+		m_signer->setSignerRole( sRole );
+		b->sign( m_signer, Signature::TM );
 		result = true;
 	}
-	catch( const Exception &e ) { setLastError( e ); }
+	catch( const Exception &e )
+	{
+		QStringList causes;
+		Exception::ExceptionCode code;
+		parseException( e, causes, code );
+		if( code == Exception::PINIncorrect )
+		{
+			setLastError( tr("PIN Incorrect") );
+			return sign( city, state, zip, country, role, role2 );
+		}
+		else
+			setLastError( e );
+	}
 	return result;
 }
 
 QSslCertificate DigiDoc::signCert() { return m_signCert; }
+QSigner *DigiDoc::signer() const { return m_signer; }
 
 bool DigiDoc::signMobile( const QString &fName )
 {
