@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -78,6 +77,8 @@ public:
 
 private:
 	void setLastError( const digidoc::Exception &e );
+	int parseException( const digidoc::Exception &e );
+	void parseExceptionStrings( const digidoc::Exception &e, QStringList &causes );
 
 	const digidoc::Signature *s;
 	QString m_lastError;
@@ -107,7 +108,6 @@ public:
 	void create( const QString &file );
 	void clear();
 	QList<digidoc::Document> documents();
-	QString getAccessCert();
 	QString fileName() const;
 	bool init();
 	bool isNull() const;
@@ -117,7 +117,7 @@ public:
 	void removeDocument( unsigned int num );
 	void removeSignature( unsigned int num );
 	void save();
-	QString getConfValue( ConfParameter parameter, const QVariant &value = QVariant() ) const;
+	static QString getConfValue( ConfParameter parameter, const QVariant &value = QVariant() );
 	static void setConfValue( ConfParameter parameter, const QVariant &value );
 	bool sign(
 		const QString &city,
@@ -127,14 +127,12 @@ public:
 		const QString &role,
 		const QString &role2 );
 	QSslCertificate signCert();
+	QSigner *signer() const;
 	bool signMobile( const QString &fName );
 	QList<DigiDocSignature> signatures();
 	digidoc::WDoc::DocumentType documentType();
 	QByteArray getFileDigest( unsigned int i );
 
-public Q_SLOTS:
-	void saveDocument( unsigned int num, const QString &filepath );
-
 Q_SIGNALS:
 	void dataChanged();
 	void error( const QString &err );
@@ -147,11 +145,11 @@ private Q_SLOTS:
 
 private:
 	bool checkDoc( bool status = false, const QString &msg = QString() );
-	bool parseException( const digidoc::Exception &e, QStringList &causes );
+	bool parseException( const digidoc::Exception &e, QStringList &causes, digidoc::Exception::ExceptionCode &code );
 	void setLastError( const digidoc::Exception &e );
 
 	digidoc::WDoc	*b;
-	QSigner			*signer;
+	QSigner			*m_signer;
 	QSslCertificate	m_signCert;
 	QStringList		m_cards;
 	QString			m_card;
