@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kõster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,17 +21,17 @@
 
 #pragma once
 
-#include <QDialog>
-#include <QDomElement>
-#include <QHash>
-#include <QHttp>
-#include <QSslError>
-#include <QTime>
-#include <QTimer>
-
 #include "ui_MobileDialog.h"
 
+#include <QHash>
+#include <QNetworkRequest>
+#include <QSslError>
+
 class DigiDoc;
+class QDomElement;
+class QNetworkAccessManager;
+class QNetworkReply;
+class QTimeLine;
 
 class MobileDialog : public QDialog, private Ui::MobileDialog
 {
@@ -46,32 +45,24 @@ public:
 	QString fName;
 
 private Q_SLOTS:
-	void sslErrors(const QList<QSslError> &);
-	void httpRequestFinished( int id, bool error );
-
-	void startSessionResult( const QDomElement &element );
-	void getSignStatusResult( const QDomElement &element );
-	void getSignStatus();
-	void updateStatus();
+	void endProgress();
+	void finished( QNetworkReply *reply );
+	void sendStatusRequest( int frame );
+	void sslErrors( QNetworkReply *reply, const QList<QSslError> &errors );
 
 private:
-	enum MobileAction {
-		MobileCreateSignature,
-		GetMobileCreateSignatureStatus
-	};
-
 	bool getFiles();
 	QString escapeChars( const QString &in ) const;
-	QString insertBody( MobileAction action, const QString &body ) const;
+	QString elementText( const QDomElement &element, const QString &tag ) const;
+	QString insertBody( const QString &action, const QString &body ) const;
 	void startSession();
 
 	DigiDoc *m_doc;
-	QHttp *m_http;
-	QTimer *m_timer, *statusTimer;
-	QTime startTime;
+	QTimeLine *statusTimer;
+	QNetworkAccessManager *manager;
+	QNetworkRequest request;
 	QString signature, files;
 
 	int sessionCode;
-	QHash< int, QByteArray > m_callBackList;
-	QHash< QByteArray, QString > lang, mobileResults;
+	QHash< QByteArray, QString > mobileResults;
 };
