@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +24,9 @@
 #include "DigiDoc.h"
 #include "version.h"
 
+#include <common/CertificateWidget.h>
 #include <common/Settings.h>
+#include <common/SslCertificate.h>
 
 #include <QDesktopServices>
 #include <QFileDialog>
@@ -56,19 +57,19 @@ SettingsDialog::SettingsDialog( QWidget *parent )
 
 	signOverwrite->setChecked( s.value( "Overwrite", false ).toBool() );
 
-	proxyHost->setText( s.value( "proxyHost" ).toString() );
-	proxyPort->setText( s.value( "proxyPort" ).toString() );
-	proxyUser->setText( s.value( "proxyUser" ).toString() );
-	proxyPass->setText( s.value( "proxyPass" ).toString() );
-	p12Cert->setText( s.value( "pkcs12Cert" ).toString() );
-	p12Pass->setText( s.value( "pkcs12Pass" ).toString() );
+	proxyHost->setText( DigiDoc::getConfValue( DigiDoc::ProxyHost ) );
+	proxyPort->setText( DigiDoc::getConfValue( DigiDoc::ProxyPort ) );
+	proxyUser->setText( DigiDoc::getConfValue( DigiDoc::ProxyUser ) );
+	proxyPass->setText( DigiDoc::getConfValue( DigiDoc::ProxyPass ) );
+	p12Cert->setText( DigiDoc::getConfValue( DigiDoc::PKCS12Cert ) );
+	p12Pass->setText( DigiDoc::getConfValue( DigiDoc::PKCS12Pass ) );
 
 	s.endGroup();
 }
 
 void SettingsDialog::on_p12Button_clicked()
 {
-	QString cert = Settings().value( "Client/pkcs12Cert" ).toString();
+	QString cert = DigiDoc::getConfValue( DigiDoc::PKCS12Cert );
 	if( cert.isEmpty() )
 		cert = QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation );
 	else
@@ -79,6 +80,9 @@ void SettingsDialog::on_p12Button_clicked()
 		setP12Cert( cert );
 }
 
+void SettingsDialog::on_p12Cert_textChanged( const QString &text )
+{ showP12Cert->setEnabled( QFile::exists( text ) ); }
+
 void SettingsDialog::on_selectDefaultDir_clicked()
 {
 	QString dir = Settings().value( "Client/DefaultDir" ).toString();
@@ -93,6 +97,20 @@ void SettingsDialog::on_selectDefaultDir_clicked()
 	defaultSameDir->setChecked( defaultDir->text().isEmpty() );
 }
 
+void SettingsDialog::on_showP12Cert_clicked()
+{
+	QFile f( p12Cert->text() );
+	if( !f.open( QIODevice::ReadOnly ) )
+		return;
+
+	PKCS12Certificate cert( &f, p12Pass->text().toLatin1() );
+	f.close();
+	if( cert.certificate().isNull() )
+		return;
+	CertificateDialog d( cert.certificate() );
+	d.exec();
+}
+
 void SettingsDialog::save()
 {
 	Settings s;
@@ -106,12 +124,6 @@ void SettingsDialog::save()
 		defaultDir->clear();
 		s.remove( "DefaultDir" );
 	}
-	s.setValue( "proxyHost", proxyHost->text() );
-	s.setValue( "proxyPort", proxyPort->text() );
-	s.setValue( "proxyUser", proxyUser->text() );
-	s.setValue( "proxyPass", proxyPass->text() );
-	s.setValue( "pkcs12Cert", p12Cert->text() );
-	s.setValue( "pkcs12Pass", p12Pass->text() );
 
 	DigiDoc::setConfValue( DigiDoc::ProxyHost, proxyHost->text() );
 	DigiDoc::setConfValue( DigiDoc::ProxyPort, proxyPort->text() );
@@ -155,21 +167,9 @@ void SettingsDialog::saveSignatureInfo(
 	s.endGroup();
 }
 
-void SettingsDialog::saveMobileInfo( const QString &code, const QString &number )
-{
-	Settings s;
-	s.beginGroup( "Client" );
-	if( s.value( "Overwrite", "false" ).toBool() )
-	{
-		s.setValue( "MobileCode", code );
-		s.setValue( "MobileNumber", number );
-	}
-	s.endGroup();
-}
-
 void SettingsDialog::setP12Cert( const QString &cert )
 {
-	Settings().setValue( "Client/pkcs12Cert", cert );
+	DigiDoc::setConfValue( DigiDoc::PKCS12Cert, cert );
 	p12Cert->setText( cert );
 	tabWidget->setCurrentIndex( 1 );
 }
