@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -41,12 +40,11 @@ public:
 		const QString &country,
 		const QString &zip,
 		bool force = false );
-	static void saveMobileInfo(
-		const QString &code,
-		const QString &number );
 
 private Q_SLOTS:
 	void on_p12Button_clicked();
+	void on_p12Cert_textChanged( const QString &text );
 	void on_selectDefaultDir_clicked();
+	void on_showP12Cert_clicked();
 	void save();
 };
