@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,13 +22,18 @@
 #include "SignatureDialog.h"
 
 #include <common/CertificateWidget.h>
+#include <common/Common.h>
 #include <common/SslCertificate.h>
 
 #include <digidocpp/Document.h>
 
 #include <QDateTime>
+#include <QDesktopServices>
+#include <QMessageBox>
 #include <QSslKey>
+#include <QTextDocument>
 #include <QTextStream>
+#include <QUrl>
 
 SignatureWidget::SignatureWidget( const DigiDocSignature &signature, unsigned int signnum, bool extended, QWidget *parent )
 :	QLabel( parent )
@@ -49,30 +53,34 @@ SignatureWidget::SignatureWidget( const DigiDocSignature &signature, unsigned in
 	else
 		st << "<img src=\":/images/ico_person_blue_16.png\">";
 
-	st << "<b>" << cert.toString( cert.isTempel() ? "CN" : "GN SN" ) << "</b>";
+	st << "<b>" << Qt::escape( cert.toString( cert.isTempel() ? "CN" : "GN SN" ) ) << "</b>";
 
+	QDateTime date = s.dateTime();
 	if( extended )
 	{
-		st << "<br />" << s.location() << "<br />";
-		st << tr("Signed on") << " "
-			<< SslCertificate::formatDate( s.dateTime(), "dd. MMMM yyyy" ) << " "
-			<< tr("time") << " "
-			<< s.dateTime().toString( "hh:mm" );
+		if( !s.location().isEmpty() )
+			st << "<br />" << Qt::escape( s.location() );
+		if( !s.role().isEmpty() )
+			st << "<br />" << Qt::escape( s.role() );
+		if( !date.isNull() )
+			st << "<br />" << tr("Signed on") << " "
+				<< SslCertificate::formatDate( date, "dd. MMMM yyyy" ) << " "
+				<< tr("time") << " "
+				<< date.toString( "hh:mm" );
 	}
 	else
 	{
 		QString tooltip;
 		QTextStream t( &tooltip );
-		QString location = s.location();
-		if( !location.isEmpty() )
-			t << location << "<br />";
-		QString role = s.role();
-		if( !role.isEmpty() )
-			t << role << "<br />";
-		t << tr("Signed on") << " "
-			<< SslCertificate::formatDate( s.dateTime(), "dd. MMMM yyyy" ) << " "
-			<< tr("time") << " "
-			<< s.dateTime().toString( "hh:mm" );
+		if( !s.location().isEmpty() )
+			t << Qt::escape( s.location() ) << "<br />";
+		if( !s.role().isEmpty() )
+			t << Qt::escape( s.role() ) << "<br />";
+		if( !date.isNull() )
+			t << tr("Signed on") << " "
+				<< SslCertificate::formatDate( date, "dd. MMMM yyyy" ) << " "
+				<< tr("time") << " "
+				<< date.toString( "hh:mm" );
 		setToolTip( tooltip );
 	}
 
@@ -107,7 +115,15 @@ void SignatureWidget::link( const QString &url )
 	if( url == "details" )
 		SignatureDialog( s, qobject_cast<QWidget*>(parent()) ).exec();
 	else if( url == "remove" )
-		Q_EMIT removeSignature( num );
+	{
+		SslCertificate c = s.cert();
+		QString msg = tr("Remove signature %1")
+			.arg( c.toString( c.isTempel() ? "CN serialNumber" : "GN SN serialNumber" ) );
+		QMessageBox::StandardButton b = QMessageBox::warning( this, msg, msg,
+			QMessageBox::Ok|QMessageBox::Cancel, QMessageBox::Cancel );
+		if( b == QMessageBox::Ok )
+			Q_EMIT removeSignature( num );
+	}
 }
 
 
@@ -123,18 +139,28 @@ SignatureDialog::SignatureDialog( const DigiDocSignature &signature, QWidget *pa
 	title->setText( titleText );
 	setWindowTitle( titleText );
 
+	QString msg;
+	QTextStream st( &msg );
 	switch( s.validate() )
 	{
-	case DigiDocSignature::Valid: error->setText( tr("Signature is valid") ); break;
+	case DigiDocSignature::Valid:
+		st << tr("Signature is valid"); break;
 	case DigiDocSignature::Invalid:
-		error->setText( tr("Signature is not valid (%1)")
-			.arg( s.lastError().isEmpty() ? tr("Unknown error") : s.lastError() ) );
+		st << "<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\"><tr>"
+			<< "<td>" << tr("Signature is not valid") << "</td>"
+			<< "<td align=\"right\"><a href=\"help\">" << tr("Help") << "</a></td>"
+			<< "</tr></table>"
+			<< "(" << (s.lastError().isEmpty() ? tr("Unknown error") : s.lastError()) << ")";
 		break;
 	case DigiDocSignature::Unknown:
-		error->setText( tr("Signature status unknown (%1)")
-			.arg( s.lastError().isEmpty() ? tr("Unknown error") : s.lastError() ) );
+		st << "<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\"><tr>"
+			<< "<td>" << tr("Signature status unknown") << "</td>"
+			<< "<td align=\"right\"><a href=\"help\">" << tr("Help") << "</a></td>"
+			<< "</tr></table>"
+			<< "(" << (s.lastError().isEmpty() ? tr("Unknown error") : s.lastError()) << ")";
 		break;
 	}
+	error->setText( msg );
 
 	const QStringList l = s.locations();
 	signerCity->setText( l.value( 0 ) );
@@ -153,8 +179,8 @@ SignatureDialog::SignatureDialog( const DigiDocSignature &signature, QWidget *pa
 	addItem( t, tr("Signature format"), s.mediaType() );
 	addItem( t, tr("Signed file count"), QString::number( s.parent()->documents().size() ) );
 	addItem( t, tr("Certificate serialnumber"), c.serialNumber() );
-	addItem( t, tr("Certificate valid at"), SslCertificate::toLocalTime( c.effectiveDate() ).toString( "dd.MM.yyyy" ) );
-	addItem( t, tr("Certificate valid until"), SslCertificate::toLocalTime( c.expiryDate() ).toString( "dd.MM.yyyy" ) );
+	addItem( t, tr("Certificate valid at"), c.effectiveDate().toLocalTime().toString( "dd.MM.yyyy" ) );
+	addItem( t, tr("Certificate valid until"), c.expiryDate().toLocalTime().toString( "dd.MM.yyyy" ) );
 	addItem( t, tr("Certificate issuer"), c.issuerInfo( QSslCertificate::CommonName ) );
 	t->resizeColumnToContents( 0 );
 
@@ -184,5 +210,8 @@ void SignatureDialog::addItem( QTreeWidget *view, const QString &variable, const
 void SignatureDialog::showCertificate()
 { CertificateDialog( s.cert(), this ).exec(); }
 
+void SignatureDialog::showHelp()
+{ Common::showHelp( s.lastError() ); }
+
 void SignatureDialog::showOCSPCertificate()
 { CertificateDialog( s.ocspCert(), this ).exec(); }
