@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,11 +24,23 @@
 #include "version.h"
 
 #include <QApplication>
+#include <QFileInfo>
 
 #include <openssl/ssl.h>
 
+#ifdef Q_OS_LINUX
+#include <QFile>
+QByteArray cryptoFileEncoder( const QString &filename ) { return filename.toUtf8(); }
+QString cryptoFileDecoder( const QByteArray &filename ) { return QString::fromUtf8( filename ); }
+#endif
+
 int main( int argc, char *argv[] )
 {
+	qputenv( "LANG", "en_US.UTF-8" );
+#ifdef Q_OS_LINUX
+	QFile::setEncodingFunction( cryptoFileEncoder );
+	QFile::setDecodingFunction( cryptoFileDecoder );
+#endif
 	QApplication a( argc, argv );
 	a.setApplicationName( APP );
 	a.setApplicationVersion( VER_STR( FILE_VER_DOT ) );
@@ -44,10 +55,10 @@ int main( int argc, char *argv[] )
 	p.setBrush( QPalette::LinkVisited, QBrush( "#509B00" ) );
 	a.setPalette( p );
 
-	int ret = 0;
 	QStringList args = a.arguments();
 	QWidget *w;
-	if( args.size() > 1 && args.value(1).right(4).toLower() == "p12d" )
+	QStringList exts = QStringList() << "p12" << "p12d";
+	if( args.size() > 1 && exts.contains( QFileInfo( args.value(1) ).suffix(), Qt::CaseInsensitive ) )
 	{
 		w = new RegisterP12( args.value(1) );
 	}
@@ -60,7 +71,7 @@ int main( int argc, char *argv[] )
 	}
 
 	w->show();
-	ret = a.exec();
+	int ret = a.exec();
 	delete w;
 	return ret;
 }
