@@ -1,8 +1,7 @@
 /*
  * QEstEidCommon
  *
- * Copyright (C) 2009 Jargo Kõster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,16 +21,48 @@
 
 #pragma once
 
+#include "sslConnect.h"
+
 #include <QThread>
 
 #include <libp11.h>
 
+#include <openssl/ssl.h>
+
+class SSLConnectPrivate
+{
+public:
+	SSLConnectPrivate();
+	~SSLConnectPrivate();
+
+	bool connectToHost( SSLConnect::RequestType type );
+	QByteArray getRequest( const QString &request ) const;
+
+	bool	unload;
+	PKCS11_CTX *p11;
+	bool	p11loaded;
+	SSL_CTX *sctx;
+	SSL		*ssl;
+
+	QString card;
+	QString pin;
+	int		reader;
+
+	unsigned int nslots;
+	PKCS11_SLOT *pslots;
+
+	SSLConnect::ErrorType error;
+	QString errorString;
+	QByteArray result;
+};
+
 class SSLThread: public QThread
 {
 	Q_OBJECT
 public:
 	SSLThread( PKCS11_SLOT *slot, QObject *parent = 0 );
-	int loginOk;
+	~SSLThread();
+	unsigned long loginResult;
 
 private:
 	void run();
