@@ -1,8 +1,7 @@
 /*
  * QDigiDocCrypto
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,7 +21,7 @@
 
 #pragma once
 
-#include "CryptDoc.h"
+#include "CryptoDoc.h"
 
 #ifdef Q_OS_WIN32
 #include <Winldap.h>
