@@ -1,8 +1,7 @@
 /*
  * QDigiDocCrypto
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,38 +23,43 @@
 
 #include <QThread>
 
-#include <QHash>
-#include <QMutex>
-#include <QSslCertificate>
+class QSslCertificate;
 
+class PollerPrivate;
 class Poller: public QThread
 {
 	Q_OBJECT
 
 public:
+	enum ErrorCode
+	{
+		NullCode = 0,
+		PinCanceled,
+		PinIncorrect,
+		PinLocked,
+	};
+
 	Poller( QObject *parent = 0 );
 	~Poller();
 
-	quint64 slot( const QString &card ) const;
-	quint64 token( const QString &card ) const;
-	void stop();
+	bool decrypt( const QByteArray &in, QByteArray &out );
+	ErrorCode errorCode() const;
 
 Q_SIGNALS:
 	void dataChanged( const QStringList &cards, const QString &card,
 		const QSslCertificate &auth );
+	void error( const QString &msg, quint8 error );
 
 private Q_SLOTS:
 	void selectCard( const QString &card );
 
 private:
+	void emitError( const QString &msg, unsigned long err, ErrorCode code = NullCode );
+	bool loadDriver();
 	void read();
-	void readCert();
 	void run();
+	void selectCert( const QString &card );
+	void unloadDriver();
 
-	Qt::HANDLE lib;
-	volatile bool terminate;
-	QMutex m;
-	QHash<QString,quint64> cards, tokens;
-	QString selectedCard, select;
-	QSslCertificate auth;
+	PollerPrivate *d;
 };
